<p align="middle">
  <img src="docs/materials/logo.png" width="200" />
</p>

# JAX-AM

[![Doc](https://img.shields.io/readthedocs/jax-am)](https://jax-am.readthedocs.io/en/latest/)
![PyPI](https://img.shields.io/pypi/v/jax-am) ![Github Star](https://img.shields.io/github/stars/tianjuxue/jax-am)
![Github Fork](https://img.shields.io/github/forks/tianjuxue/jax-am)
![License](https://img.shields.io/github/license/tianjuxue/jax-am)

A GPU-accelerated simulation toolbox for additive manufacturing based on [JAX](https://github.com/google/jax).

## Documentation

Please see the [web documentation](https://jax-am.readthedocs.io/en/latest/) for details of this project.
